Welcome to mirror list, hosted at ThFree Co, Russian Federation.

cygwin.com/git/newlib-cygwin.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorCorinna Vinschen <corinna@vinschen.de>2007-02-26 15:39:25 +0300
committerCorinna Vinschen <corinna@vinschen.de>2007-02-26 15:39:25 +0300
commit14e06cca26d10be79606054ff17eecc573db25db (patch)
tree292893c3b6a5b78948f293b520d5406abcbca0ad /winsup/cygwin/syslog.cc
parent457c7938f020cabd6029ab976ccfc35ba86d5369 (diff)
* fhandler_registry.cc (registry_listing): Drop name of HKEY_DYN_DATA.
(registry_keys): Drop HKEY_DYN_DATA. * net.cc: Fix comment. * syslog.cc: Ditto.
Diffstat (limited to 'winsup/cygwin/syslog.cc')
-rw-r--r--winsup/cygwin/syslog.cc19
1 files changed, 8 insertions, 11 deletions
diff --git a/winsup/cygwin/syslog.cc b/winsup/cygwin/syslog.cc
index d5d85e7df..383cc244f 100644
--- a/winsup/cygwin/syslog.cc
+++ b/winsup/cygwin/syslog.cc
@@ -30,8 +30,7 @@ details. */
#define CYGWIN_LOG_NAME "Cygwin"
-/* openlog: save the passed args. Don't open the
- system log (NT) or log file (95) yet. */
+/* openlog: save the passed args. Don't open the system log or /dev/log yet. */
extern "C" void
openlog (const char *ident, int logopt, int facility)
{
@@ -259,15 +258,13 @@ try_connect_syslogd (int priority, const char *msg, int len)
return ret;
}
-/*
- * syslog: creates the log message and writes to system
- * log (NT) or log file (95). FIXME. WinNT log error messages
- * don't look pretty, but in order to fix this we have to
- * embed resources in the code and tell the NT registry
- * where we are, blech (what happens if we move ?).
- * We could, however, add the resources in Cygwin and
- * always point to that.
- */
+/* syslog: creates the log message and writes to /dev/log, or to the
+ NT system log if /dev/log isn't available.
+
+ FIXME. WinNT system log messages don't look pretty, but in order to
+ fix this we have to embed resources in the code and tell the NT
+ registry where we are, blech (what happens if we move ?). We could,
+ however, add the resources in Cygwin and always point to that. */
extern "C" void
vsyslog (int priority, const char *message, va_list ap)